/*
 * Copyright (c) 2022-present Charles7c Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package top.charles7c.continew.admin.system.mapper;

import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import top.charles7c.continew.admin.common.config.mybatis.DataPermissionMapper;
import top.charles7c.continew.admin.system.model.entity.UserDO;

/**
 * 用户 Mapper
 *
 * @author Charles7c
 * @since 2022/12/22 21:47
 */
public interface UserMapper extends DataPermissionMapper<UserDO> {

    /**
     * 根据用户名查询
     *
     * @param username
     *            用户名
     * @return 用户信息
     */
    @Select("SELECT * FROM `sys_user` WHERE `username` = #{username}")
    UserDO selectByUsername(@Param("username") String username);

    /**
     * 根据手机号查询
     *
     * @param phone
     *            手机号
     * @return 用户信息
     */
    @Select("SELECT * FROM `sys_user` WHERE `phone` = #{phone}")
    UserDO selectByPhone(@Param("phone") String phone);

    /**
     * 根据邮箱查询
     *
     * @param email
     *            邮箱
     * @return 用户信息
     */
    @Select("SELECT * FROM `sys_user` WHERE `email` = #{email}")
    UserDO selectByEmail(@Param("email") String email);

    /**
     * 根据 ID 查询昵称
     *
     * @param id
     *            ID
     * @return 昵称
     */
    @Select("SELECT `nickname` FROM `sys_user` WHERE `id` = #{id}")
    String selectNicknameById(@Param("id") Long id);
}
